Tutorials
=========

This section contains tutorials that teach the use of pyLife and its
principles.  As opposed to the :doc:`/cookbook` it does not show actual
workflows.

.. toctree::
   :maxdepth: 1

   demos/woehler_curve.nblink
   demos/load_collective.nblink
   demos/stress-strength.nblink
